@@ -7,11 +7,10 @@
  * this program the details of the active license.
  */
 use datafusion::arrow::datatypes::{DataType, Field};
-use datafusion::physical_plan::functions::{Signature, Volatility};
 use datafusion::physical_plan::udf::ScalarUDF;
 use datafusion::physical_plan::ColumnarValue;
 use datafusion::scalar::ScalarValue;
-use datafusion_expr::{ReturnTypeFunction, ScalarFunctionImplementation};
+use datafusion_expr::{ReturnTypeFunction, ScalarFunctionImplementation, Signature, Volatility};
 use std::convert::TryFrom;
 use std::sync::Arc;
 use vegafusion_core::data::scalar::ScalarValueHelpers;
